pub struct QueryClient<T> { /* private fields */ }Expand description
Query defines the gRPC querier service.
Implementations
Sourceimpl QueryClient<Channel>
impl QueryClient<Channel>
Sourceimpl<T> QueryClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> QueryClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> QueryClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn event_params(
&mut self,
request: impl IntoRequest<QueryEventParamsRequest>,
) -> Result<Response<QueryEventParamsResponse>, Status>
pub async fn event_params( &mut self, request: impl IntoRequest<QueryEventParamsRequest>, ) -> Result<Response<QueryEventParamsResponse>, Status>
Queries the EventParams.
Sourcepub async fn propose_params(
&mut self,
request: impl IntoRequest<QueryProposeParamsRequest>,
) -> Result<Response<QueryProposeParamsResponse>, Status>
pub async fn propose_params( &mut self, request: impl IntoRequest<QueryProposeParamsRequest>, ) -> Result<Response<QueryProposeParamsResponse>, Status>
Queries the ProposeParams.
Sourcepub async fn safety_params(
&mut self,
request: impl IntoRequest<QuerySafetyParamsRequest>,
) -> Result<Response<QuerySafetyParamsResponse>, Status>
pub async fn safety_params( &mut self, request: impl IntoRequest<QuerySafetyParamsRequest>, ) -> Result<Response<QuerySafetyParamsResponse>, Status>
Queries the SafetyParams.
Sourcepub async fn acknowledged_event_info(
&mut self,
request: impl IntoRequest<QueryAcknowledgedEventInfoRequest>,
) -> Result<Response<QueryAcknowledgedEventInfoResponse>, Status>
pub async fn acknowledged_event_info( &mut self, request: impl IntoRequest<QueryAcknowledgedEventInfoRequest>, ) -> Result<Response<QueryAcknowledgedEventInfoResponse>, Status>
Queries the AcknowledgedEventInfo. An “acknowledged” event is one that is in-consensus and has been stored in-state.
Sourcepub async fn recognized_event_info(
&mut self,
request: impl IntoRequest<QueryRecognizedEventInfoRequest>,
) -> Result<Response<QueryRecognizedEventInfoResponse>, Status>
pub async fn recognized_event_info( &mut self, request: impl IntoRequest<QueryRecognizedEventInfoRequest>, ) -> Result<Response<QueryRecognizedEventInfoResponse>, Status>
Queries the RecognizedEventInfo. A “recognized” event is one that is finalized on the Ethereum blockchain and has been identified by the queried node. It is not yet in-consensus.
Sourcepub async fn delayed_complete_bridge_messages(
&mut self,
request: impl IntoRequest<QueryDelayedCompleteBridgeMessagesRequest>,
) -> Result<Response<QueryDelayedCompleteBridgeMessagesResponse>, Status>
pub async fn delayed_complete_bridge_messages( &mut self, request: impl IntoRequest<QueryDelayedCompleteBridgeMessagesRequest>, ) -> Result<Response<QueryDelayedCompleteBridgeMessagesResponse>, Status>
Queries all MsgCompleteBridge messages that are delayed (not yet
executed) and corresponding block heights at which they will execute.