pub struct BlockMessageIds {
pub ids: Vec<u32>,
}Expand description
BlockMessageIds stores the id of each message that should be processed at a given block height.
Fields
ids: Vec<u32>ids stores a list of DelayedMessage ids that should be processed at a given block height.