pub struct MapValue {
pub entries: Vec<Entry>,
}Expand description
A map.
Wrapped in a message so ‘not set’ and empty can be differentiated, which is required for use in a ‘oneof’.
Fields
entries: Vec<Entry>The set of map entries.
CEL has fewer restrictions on keys, so a protobuf map represenation cannot be used.