pub struct MethodSettings {
pub selector: String,
pub long_running: Option<LongRunning>,
}Expand description
Describes the generator configuration for a method.
Fields
selector: StringThe fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
long_running: Option<LongRunning>Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto.
Example of a YAML configuration::
publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes